@@ -1,4 +1,4 @@
-# $Id: Chado.pm,v 1.75 2009/03/03 21:03:59 scottcain Exp $
+# $Id: Chado.pm,v 1.78 2009/03/20 18:59:22 scottcain Exp $
 
 =head1 NAME
 
@@ -806,6 +806,20 @@ sub _by_alias_by_name {
   my ($name, $class, $ref, $base_start, $stop, $operation) 
        = $self->_rearrange([qw(NAME CLASS REF START END OPERATION)],@_);
 
+  if ($name =~ /^id:(\d+)/) {
+    my $feature_id = $1;
+    return $self->get_feature_by_feature_id($feature_id);
+  }
+
+  my @temp_array = split /:/, $name;
+  if (scalar @temp_array == 2) {
+    if ($self->source2dbxref($temp_array[0]) > 0) {
+      warn "assuming that the name with a colon ($name) is coming from a multiple hit search result (ie, is of the form 'source:name'";
+      $name = $temp_array[1];
+    }
+  }
+
+
   my $wildcard = 0;
   if ($name =~ /\*/) {
     $wildcard = 1;
@@ -964,6 +978,9 @@ sub _by_alias_by_name {
 
     # getting feature info
   while (my $feature_id_ref = $sth->fetchrow_hashref) {
+
+    warn "feature_id in features method loop:".$$feature_id_ref{feature_id} if DEBUG;
+
     $isth->execute($$feature_id_ref{'feature_id'},$self->gff_source_db_id)
              or $self->throw("getting feature info failed");
 
@@ -1014,7 +1031,7 @@ sub _by_alias_by_name {
         my $src_name = $jsth->fetchrow_hashref;
         warn "src_name:$$src_name{'name'}" if DEBUG;
         $parent_segment =
-             Bio::DB::Das::Chado::Segment->new($$src_name{'name'},$self);
+             Bio::DB::Das::Chado::Segment->new($$src_name{'name'},$self,undef,undef,undef,undef,$$hashref{'srcfeature_id'});
         $old_srcfeature_id=$$hashref{'srcfeature_id'};
       }
         #now build the feature
@@ -1047,6 +1064,11 @@ sub _by_alias_by_name {
           $interbase_start = $$hashref{'fmin'};
         }
         $base_start = $interbase_start +1;
+
+        my $type_obj =  Bio::DB::GFF::Typename->new(
+                     $self->term2name($$hashref{type_id}),
+                     $self->dbxref2source($$hashref{dbxref_id}) || "");
+
         my $feat = Bio::DB::Das::Chado::Segment::Feature->new(
                                         $self,
                                         $parent_segment,
@@ -1129,12 +1151,17 @@ sub _by_alias_by_name {
                     $stop = $$exonref{fmax};
                 }
 
+                my $type_obj = Bio::DB::GFF::Typename->new(
+                     'CDS',
+                     $self->dbxref2source($$hashref{'dbxref_id'}) || '');
+
+
                         my $feat = Bio::DB::Das::Chado::Segment::Feature->new(
                                         $self,
                                         $parent_segment,
                                         $parent_segment->seq_id,
                                         $start,$stop,
-                                        'CDS',
+                                        $type_obj,
                                         $$hashref{'score'},
                                         $$hashref{'strand'},
                                         $$hashref{'phase'},
@@ -1151,12 +1178,18 @@ sub _by_alias_by_name {
          #the normal case where you don't infer CDS features 
             my $interbase_start = $$hashref{'fmin'};
             $base_start = $interbase_start +1;
+
+            my $type_obj = Bio::DB::GFF::Typename->new(
+                   $self->term2name($$hashref{'type_id'}),
+                   $self->dbxref2source($$hashref{'dbxref_id'}) || '');
+
+
             my $feat = Bio::DB::Das::Chado::Segment::Feature->new(
                                         $self,
                                         $parent_segment,
                                         $parent_segment->seq_id,
                                         $base_start,$$hashref{'fmax'},
-                                        $self->term2name($$hashref{'type_id'}),
+                                        $type_obj,
                                         $$hashref{'score'},
                                         $$hashref{'strand'},
                                         $$hashref{'phase'},
@@ -1185,6 +1218,14 @@ sub get_feature_by_feature_id {
   return @features;
 }
 
+sub get_feature_by_id {
+  my $self = shift;
+  my $f_id = shift;
+
+  my @features = $self->features(-feature_id => $f_id);
+  return $features[0];
+}
+
 *fetch = *get_feature_by_primary_id = \&get_feature_by_feature_id;
 
 sub _complex_search {
