@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser::Session;
 
-# $Id: Session.pm,v 1.10 2009/01/26 23:11:21 lstein Exp $
+# $Id: Session.pm,v 1.12 2009/03/10 13:57:24 lstein Exp $
 
 use strict;
 use warnings;
@@ -25,7 +25,9 @@ sub new {
   $self->lock($id) if $id;
   $self->{session}    = CGI::Session->new($driver,$id,$session_args);
   $self->lock($self->{session}->id) unless $id;  # if we have a newly-created ID, then lock now
+  warn "[$$] session fetch for ",$self->id if DEBUG;
   $self->source($default_source) unless defined $self->source;
+  $self->{pid} = $$;
   $self;
 }
 
@@ -48,6 +50,7 @@ sub lock {
 
 sub unlock {
     my $self     = shift;
+    warn "[$$] session unlock" if DEBUG;
     return unless $self->lockfh;
     close $self->lockfh;
     $self->lockfh(undef);
@@ -63,7 +66,11 @@ sub lockfile {
 
 sub flush {
   my $self = shift;
+  return unless $$ == $self->{pid};
+  warn "[$$] session flush for ",$self->id if DEBUG;
   $self->{session}->flush if $self->{session};
+  warn "[$$] SESSION FLUSH ERROR: ",$self->{session}->errstr 
+      if $self->{session}->errstr;
 }
 
 sub modified {
@@ -86,7 +93,7 @@ sub session { shift->{session} }
 
 sub page_settings {
   my $self        = shift;
-  my $hash                 = $self->config_hash;
+  my $hash        = $self->config_hash;
   $hash->{page_settings} ||= {};
   $hash->{page_settings}{userid} = $self->id;     # store the id in our state
   return $hash->{page_settings};
@@ -110,16 +117,19 @@ sub source {
 
 sub config_hash {
   my $self = shift;
-  my $source = $self->source;
+  my $source  = $self->source;
   my $session = $self->{session};
   $session->param($source=>{}) unless $session->param($source);
   return $session->param($source);
 }
 
-sub DESTROY {
-    my $self = shift;
-    $self->flush;
-    $self->unlock;
-}
+# problem with explicit DESTROY is that it gets called in all child
+# processes. Better to have the unlock happen when filehandle is truly
+# destroyed.
+#sub DESTROY {
+#    my $self = shift;
+#    $self->flush;
+#    $self->unlock;
+#}
 
 1;
